@@ -14,21 +14,13 @@ import io
 import os
 import random
 import struct
-import sys
 import time
 import zlib
 
-
-if sys.version_info[0] >= 3:
-    bio = io.BytesIO
-else:
-    import cStringIO
-
-    bio = cStringIO.StringIO
-
-
 import zstandard as zstd
 
+bio = io.BytesIO
+
 
 def timer(fn, miniter=3, minwall=3.0):
     """Runs fn() multiple times and returns the results.
@@ -89,7 +81,7 @@ def bench(
     def wrapper(fn):
         if not fn.__name__.startswith(("compress_", "decompress_")):
             raise ValueError(
-                "benchmark function must begin with " "compress_ or decompress_"
+                "benchmark function must begin with compress_ or decompress_"
             )
 
         fn.mode = mode
@@ -209,7 +201,7 @@ def compress_compressobj_size(chunks, zparams):
 
 
 @bench("discrete", "chunker()")
-def compress_chunker(chunks, zparams):
+def compress_chunker_discrete(chunks, zparams):
     cctx = zstd.ZstdCompressor(compression_params=zparams)
     for in_chunk in chunks:
         chunker = cctx.chunker()
@@ -220,7 +212,7 @@ def compress_chunker(chunks, zparams):
 
 
 @bench("discrete", "chunker() w/ input size")
-def compress_chunker(chunks, zparams):
+def compress_chunker_discrete_size(chunks, zparams):
     cctx = zstd.ZstdCompressor(compression_params=zparams)
     for in_chunk in chunks:
         chunker = cctx.chunker(size=len(in_chunk))
@@ -797,18 +789,17 @@ if __name__ == "__main__":
     group.add_argument(
         "--stream",
         action="store_true",
-        help="Feed each input into a stream and emit " "flushed blocks",
+        help="Feed each input into a stream and emit flushed blocks",
     )
     group.add_argument(
         "--content-dict",
         action="store_true",
-        help="Compress each input using the previous as a "
-        "content dictionary",
+        help="Compress each input using the previous as a content dictionary",
     )
     group.add_argument(
         "--discrete-dict",
         action="store_true",
-        help="Compress each input independently with a " "dictionary",
+        help="Compress each input independently with a dictionary",
     )
 
     group = parser.add_argument_group("Benchmark Selection")
@@ -862,7 +853,7 @@ if __name__ == "__main__":
     group.add_argument(
         "--compress-threads",
         type=int,
-        help="Use multi-threaded compression with this many " "threads",
+        help="Use multi-threaded compression with this many threads",
     )
     group.add_argument(
         "--batch-threads",
@@ -893,7 +884,7 @@ if __name__ == "__main__":
     group.add_argument(
         "--dict-sample-limit",
         type=int,
-        help="limit how many samples are fed into dictionary " "training",
+        help="limit how many samples are fed into dictionary training",
     )
     group.add_argument(
         "--chunk-encoding",
@@ -905,7 +896,7 @@ if __name__ == "__main__":
     group.add_argument(
         "--split-input-size",
         type=int,
-        help="Split inputs into chunks so they are at most this " "many bytes",
+        help="Split inputs into chunks so they are at most this many bytes",
     )
 
     parser.add_argument("path", metavar="PATH", nargs="+")
