@@ -30,6 +30,8 @@ struct ZstdCompressor {
     cctx: Arc<CCtx<'static>>,
 }
 
+unsafe impl Sync for ZstdCompressor {}
+
 impl ZstdCompressor {
     pub(crate) fn setup_cctx(&self, py: Python) -> PyResult<()> {
         self.cctx
@@ -160,7 +162,7 @@ impl ZstdCompressor {
         ))
     }
 
-    fn compress<'p>(&self, py: Python<'p>, buffer: PyBuffer<u8>) -> PyResult<&'p PyBytes> {
+    fn compress<'p>(&self, py: Python<'p>, buffer: PyBuffer<u8>) -> PyResult<Bound<'p, PyBytes>> {
         let source: &[u8] =
             unsafe { std::slice::from_raw_parts(buffer.buf_ptr() as *const _, buffer.len_bytes()) };
 
@@ -219,8 +221,8 @@ impl ZstdCompressor {
     fn copy_stream(
         &self,
         py: Python,
-        ifh: &PyAny,
-        ofh: &PyAny,
+        ifh: &Bound<'_, PyAny>,
+        ofh: &Bound<'_, PyAny>,
         size: Option<u64>,
         read_size: Option<usize>,
         write_size: Option<usize>,
@@ -262,7 +264,7 @@ impl ZstdCompressor {
             // Try to read from source stream.
             let read_object = ifh.call_method("read", (read_size,), None)?;
 
-            let read_bytes: &PyBytes = read_object.downcast()?;
+            let read_bytes = read_object.downcast::<PyBytes>()?;
             let read_data = read_bytes.as_bytes();
 
             // If no data was read we are at EOF.
@@ -336,7 +338,7 @@ impl ZstdCompressor {
     fn multi_compress_to_buffer(
         &self,
         py: Python,
-        data: &PyAny,
+        data: &Bound<'_, PyAny>,
         threads: isize,
     ) -> PyResult<ZstdBufferWithSegmentsCollection> {
         multi_compress_to_buffer(py, &self.params, &self.dict, data, threads)
@@ -346,7 +348,7 @@ impl ZstdCompressor {
     fn read_to_iter(
         &self,
         py: Python,
-        reader: &PyAny,
+        reader: &Bound<'_, PyAny>,
         size: Option<u64>,
         read_size: Option<usize>,
         write_size: Option<usize>,
@@ -364,7 +366,7 @@ impl ZstdCompressor {
     fn stream_reader(
         &self,
         py: Python,
-        source: &PyAny,
+        source: &Bound<'_, PyAny>,
         size: Option<u64>,
         read_size: Option<usize>,
         closefd: bool,
@@ -381,7 +383,7 @@ impl ZstdCompressor {
     fn stream_writer(
         &self,
         py: Python,
-        writer: &PyAny,
+        writer: &Bound<'_, PyAny>,
         size: Option<u64>,
         write_size: Option<usize>,
         write_return_read: bool,
@@ -410,7 +412,7 @@ impl ZstdCompressor {
     }
 }
 
-pub(crate) fn init_module(module: &PyModule) -> PyResult<()> {
+pub(crate) fn init_module(module: &Bound<'_, PyModule>) -> PyResult<()> {
     module.add_class::<ZstdCompressor>()?;
 
     Ok(())
