@@ -11,6 +11,7 @@ use {
         exceptions::{PyOSError, PyValueError},
         prelude::*,
         types::PyBytes,
+        IntoPyObjectExt,
     },
     std::sync::Arc,
 };
@@ -27,18 +28,20 @@ pub struct ZstdDecompressionWriter {
     closed: bool,
 }
 
+unsafe impl Sync for ZstdDecompressionWriter {}
+
 impl ZstdDecompressionWriter {
     pub fn new(
         py: Python,
         dctx: Arc<DCtx<'static>>,
-        writer: &PyAny,
+        writer: &Bound<'_, PyAny>,
         write_size: usize,
         write_return_read: bool,
         closefd: bool,
     ) -> PyResult<Self> {
         Ok(Self {
             dctx,
-            writer: writer.into_py(py),
+            writer: writer.into_py_any(py)?,
             write_size,
             write_return_read,
             closefd,
@@ -160,7 +163,7 @@ impl ZstdDecompressionWriter {
 
     #[pyo3(signature = (size=None))]
     #[allow(unused_variables)]
-    fn readline(&self, py: Python, size: Option<&PyAny>) -> PyResult<()> {
+    fn readline(&self, py: Python, size: Option<&Bound<'_, PyAny>>) -> PyResult<()> {
         let io = py.import("io")?;
         let exc = io.getattr("UnsupportedOperation")?;
 
@@ -169,7 +172,7 @@ impl ZstdDecompressionWriter {
 
     #[pyo3(signature = (hint=None))]
     #[allow(unused_variables)]
-    fn readlines(&self, py: Python, hint: Option<&PyAny>) -> PyResult<()> {
+    fn readlines(&self, py: Python, hint: Option<&Bound<'_, PyAny>>) -> PyResult<()> {
         let io = py.import("io")?;
         let exc = io.getattr("UnsupportedOperation")?;
 
@@ -198,7 +201,7 @@ impl ZstdDecompressionWriter {
 
     #[pyo3(signature = (size=None))]
     #[allow(unused_variables)]
-    fn truncate(&self, py: Python, size: Option<&PyAny>) -> PyResult<()> {
+    fn truncate(&self, py: Python, size: Option<&Bound<'_, PyAny>>) -> PyResult<()> {
         let io = py.import("io")?;
         let exc = io.getattr("UnsupportedOperation")?;
 
@@ -211,7 +214,7 @@ impl ZstdDecompressionWriter {
 
     #[pyo3(signature = (lines))]
     #[allow(unused_variables)]
-    fn writelines(&self, py: Python, lines: &PyAny) -> PyResult<()> {
+    fn writelines(&self, py: Python, lines: &Bound<'_, PyAny>) -> PyResult<()> {
         let io = py.import("io")?;
         let exc = io.getattr("UnsupportedOperation")?;
 
@@ -235,7 +238,7 @@ impl ZstdDecompressionWriter {
     }
 
     #[allow(unused_variables)]
-    fn readinto(&self, py: Python, buffer: &PyAny) -> PyResult<()> {
+    fn readinto(&self, py: Python, buffer: &Bound<'_, PyAny>) -> PyResult<()> {
         let io = py.import("io")?;
         let exc = io.getattr("UnsupportedOperation")?;
 
@@ -252,7 +255,7 @@ impl ZstdDecompressionWriter {
     }
 
     #[allow(unused_variables)]
-    fn readinto1(&self, py: Python, buffer: &PyAny) -> PyResult<()> {
+    fn readinto1(&self, py: Python, buffer: &Bound<'_, PyAny>) -> PyResult<()> {
         let io = py.import("io")?;
         let exc = io.getattr("UnsupportedOperation")?;
 
