@@ -19,7 +19,7 @@ use {
         types::{PyBytes, PyList},
         wrap_pyfunction,
     },
-    std::sync::Arc,
+    std::{ffi::c_ulonglong, sync::Arc},
 };
 
 #[pyclass(module = "zstandard.backend_rust")]
@@ -30,6 +30,8 @@ struct ZstdDecompressor {
     dctx: Arc<DCtx<'static>>,
 }
 
+unsafe impl Sync for ZstdDecompressor {}
+
 impl ZstdDecompressor {
     fn setup_dctx(&self, py: Python, load_dict: bool) -> PyResult<()> {
         self.dctx.reset().map_err(|msg| {
@@ -67,9 +69,9 @@ impl ZstdDecompressor {
         max_window_size: usize,
         format: u32,
     ) -> PyResult<Self> {
-        let format = if format == zstd_sys::ZSTD_format_e::ZSTD_f_zstd1 as _ {
+        let format = if format == zstd_sys::ZSTD_format_e::ZSTD_f_zstd1 as u32 {
             zstd_sys::ZSTD_format_e::ZSTD_f_zstd1
-        } else if format == zstd_sys::ZSTD_format_e::ZSTD_f_zstd1_magicless as _ {
+        } else if format == zstd_sys::ZSTD_format_e::ZSTD_f_zstd1_magicless as u32 {
             zstd_sys::ZSTD_format_e::ZSTD_f_zstd1_magicless
         } else {
             return Err(PyValueError::new_err(format!("invalid format value")));
@@ -89,8 +91,8 @@ impl ZstdDecompressor {
     fn copy_stream(
         &self,
         py: Python,
-        ifh: &PyAny,
-        ofh: &PyAny,
+        ifh: &Bound<'_, PyAny>,
+        ofh: &Bound<'_, PyAny>,
         read_size: Option<usize>,
         write_size: Option<usize>,
     ) -> PyResult<(usize, usize)> {
@@ -125,7 +127,7 @@ impl ZstdDecompressor {
         // Read all available input.
         loop {
             let read_object = ifh.call_method1("read", (read_size,))?;
-            let read_bytes: &PyBytes = read_object.downcast()?;
+            let read_bytes = read_object.downcast::<PyBytes>()?;
             let read_data = read_bytes.as_bytes();
 
             if read_data.len() == 0 {
@@ -167,7 +169,7 @@ impl ZstdDecompressor {
         max_output_size: usize,
         read_across_frames: bool,
         allow_extra_data: bool,
-    ) -> PyResult<&'p PyBytes> {
+    ) -> PyResult<Bound<'p, PyBytes>> {
         if read_across_frames {
             return Err(ZstdError::new_err(
                 "ZstdDecompressor.read_across_frames=True is not yet implemented",
@@ -176,27 +178,35 @@ impl ZstdDecompressor {
 
         self.setup_dctx(py, true)?;
 
-        let output_size =
-            unsafe { zstd_sys::ZSTD_getFrameContentSize(buffer.buf_ptr(), buffer.len_bytes()) };
+        let mut header: zstd_sys::ZSTD_FrameHeader = unsafe { std::mem::zeroed() };
+        let zresult = unsafe {
+            zstd_sys::ZSTD_getFrameHeader_advanced(
+                &mut header,
+                buffer.buf_ptr(),
+                buffer.len_bytes(),
+                self.format,
+            )
+        };
 
-        let (output_buffer_size, output_size) =
-            if output_size == zstd_sys::ZSTD_CONTENTSIZE_ERROR as _ {
+        if zresult != 0 {
+            return Err(ZstdError::new_err(
+                "error determining content size from frame header",
+            ));
+        }
+
+        let (output_buffer_size, output_size) = if header.frameContentSize == 0 {
+            return Ok(PyBytes::new(py, &[]));
+        } else if header.frameContentSize == zstd_sys::ZSTD_CONTENTSIZE_UNKNOWN as c_ulonglong {
+            if max_output_size == 0 {
                 return Err(ZstdError::new_err(
-                    "error determining content size from frame header",
+                    "could not determine content size in frame header",
                 ));
-            } else if output_size == 0 {
-                return Ok(PyBytes::new(py, &[]));
-            } else if output_size == zstd_sys::ZSTD_CONTENTSIZE_UNKNOWN as _ {
-                if max_output_size == 0 {
-                    return Err(ZstdError::new_err(
-                        "could not determine content size in frame header",
-                    ));
-                }
+            }
 
-                (max_output_size, 0)
-            } else {
-                (output_size as _, output_size)
-            };
+            (max_output_size, 0)
+        } else {
+            (header.frameContentSize as _, header.frameContentSize)
+        };
 
         let mut dest_buffer: Vec<u8> = Vec::new();
         dest_buffer
@@ -218,7 +228,7 @@ impl ZstdDecompressor {
             Err(ZstdError::new_err(
                 "decompression error: did not decompress full frame",
             ))
-        } else if output_size != 0 && dest_buffer.len() != output_size as _ {
+        } else if output_size != 0 && dest_buffer.len() != output_size as usize {
             Err(ZstdError::new_err(format!(
                 "decompression error: decompressed {} bytes; expected {}",
                 zresult, output_size
@@ -237,8 +247,8 @@ impl ZstdDecompressor {
     fn decompress_content_dict_chain<'p>(
         &self,
         py: Python<'p>,
-        frames: &PyList,
-    ) -> PyResult<&'p PyBytes> {
+        frames: &Bound<'_, PyList>,
+    ) -> PyResult<Bound<'p, PyBytes>> {
         if frames.is_empty() {
             return Err(PyValueError::new_err("empty input chain"));
         }
@@ -246,16 +256,16 @@ impl ZstdDecompressor {
         // First chunk should not be using a dictionary. We handle it specially.
         let chunk = frames.get_item(0)?;
 
-        if !chunk.is_instance_of::<PyBytes>()? {
+        if !chunk.is_instance_of::<PyBytes>() {
             return Err(PyValueError::new_err("chunk 0 must be bytes"));
         }
 
-        let chunk_buffer: PyBuffer<u8> = PyBuffer::get(chunk)?;
-        let mut params = zstd_sys::ZSTD_frameHeader {
+        let chunk_buffer: PyBuffer<u8> = PyBuffer::get(&chunk.as_borrowed())?;
+        let mut params = zstd_sys::ZSTD_FrameHeader {
             frameContentSize: 0,
             windowSize: 0,
             blockSizeMax: 0,
-            frameType: zstd_sys::ZSTD_frameType_e::ZSTD_frame,
+            frameType: zstd_sys::ZSTD_FrameType_e::ZSTD_frame,
             headerSize: 0,
             dictID: 0,
             checksumFlag: 0,
@@ -310,11 +320,11 @@ impl ZstdDecompressor {
         }
 
         for (i, chunk) in frames.iter().enumerate().skip(1) {
-            if !chunk.is_instance_of::<PyBytes>()? {
+            if !chunk.is_instance_of::<PyBytes>() {
                 return Err(PyValueError::new_err(format!("chunk {} must be bytes", i)));
             }
 
-            let chunk_buffer: PyBuffer<u8> = PyBuffer::get(chunk)?;
+            let chunk_buffer: PyBuffer<u8> = PyBuffer::get(&chunk.as_borrowed())?;
 
             let zresult = unsafe {
                 zstd_sys::ZSTD_getFrameHeader(
@@ -400,8 +410,8 @@ impl ZstdDecompressor {
     fn multi_decompress_to_buffer(
         &self,
         py: Python,
-        frames: &PyAny,
-        decompressed_sizes: Option<&PyAny>,
+        frames: &Bound<'_, PyAny>,
+        decompressed_sizes: Option<&Bound<'_, PyAny>>,
         threads: isize,
     ) -> PyResult<ZstdBufferWithSegmentsCollection> {
         self.setup_dctx(py, true)?;
@@ -419,7 +429,7 @@ impl ZstdDecompressor {
     fn read_to_iter(
         &self,
         py: Python,
-        reader: &PyAny,
+        reader: &Bound<'_, PyAny>,
         read_size: Option<usize>,
         write_size: Option<usize>,
         skip_bytes: Option<usize>,
@@ -456,7 +466,7 @@ impl ZstdDecompressor {
     fn stream_reader(
         &self,
         py: Python,
-        source: &PyAny,
+        source: &Bound<'_, PyAny>,
         read_size: Option<usize>,
         read_across_frames: bool,
         closefd: bool,
@@ -479,7 +489,7 @@ impl ZstdDecompressor {
     fn stream_writer(
         &self,
         py: Python,
-        writer: &PyAny,
+        writer: &Bound<'_, PyAny>,
         write_size: Option<usize>,
         write_return_read: bool,
         closefd: bool,
@@ -504,7 +514,7 @@ fn estimate_decompression_context_size() -> usize {
     unsafe { zstd_sys::ZSTD_estimateDCtxSize() }
 }
 
-pub(crate) fn init_module(module: &PyModule) -> PyResult<()> {
+pub(crate) fn init_module(module: &Bound<'_, PyModule>) -> PyResult<()> {
     module.add_class::<ZstdDecompressor>()?;
     module.add_function(wrap_pyfunction!(
         estimate_decompression_context_size,
