@@ -8,8 +8,8 @@ import unittest
 import zstandard as zstd
 
 from .common import (
-    NonClosingBytesIO,
     CustomBytesIO,
+    NonClosingBytesIO,
 )
 
 
@@ -22,6 +22,12 @@ class TestCompressor_stream_writer(unittest.TestCase):
         self.assertFalse(writer.isatty())
         self.assertFalse(writer.readable())
 
+        with self.assertRaises(io.UnsupportedOperation):
+            writer.__iter__()
+
+        with self.assertRaises(io.UnsupportedOperation):
+            writer.__next__()
+
         with self.assertRaises(io.UnsupportedOperation):
             writer.readline()
 
@@ -295,7 +301,7 @@ class TestCompressor_stream_writer(unittest.TestCase):
         d = zstd.train_dictionary(8192, samples)
 
         h = hashlib.sha1(d.as_bytes()).hexdigest()
-        self.assertEqual(h, "e739fb6cecd613386b8fffc777f756f5e6115e73")
+        self.assertEqual(h, "f32ddfbe0878bbd428afc00b17810387c6752191")
 
         buffer = io.BytesIO()
         cctx = zstd.ZstdCompressor(level=9, dict_data=d)
@@ -308,12 +314,12 @@ class TestCompressor_stream_writer(unittest.TestCase):
 
         params = zstd.get_frame_parameters(compressed)
         self.assertEqual(params.content_size, zstd.CONTENTSIZE_UNKNOWN)
-        self.assertEqual(params.window_size, 1024)
+        self.assertEqual(params.window_size, 4194304)
         self.assertEqual(params.dict_id, d.dict_id())
         self.assertFalse(params.has_checksum)
 
         h = hashlib.sha1(compressed).hexdigest()
-        self.assertEqual(h, "7cdf9c1f7f7918c7f57c9f6627d46fb599893755")
+        self.assertEqual(h, "f8ca6ebe269a822615e86d710c74d61cb4d4e3ca")
 
         source = b"foo" + b"bar" + (b"foo" * 16384)
 
